Files
project_6/cccl_upstream/cudax/test/stf/freeze/freeze_rw.cu
muh-bot dedf08166a [CCCL] Add missing CCCL components: c2h, nvbench_helper, cmake, cudax, AGENTS.md
Added 863 files from NVIDIA/cccl sparse checkout:
- c2h/ (27 files): Catch2 test helpers — generators, validators, runner
- nvbench_helper/ (10 files): Benchmark harness utilities
- cmake/ (29 files): CMake presets and build helpers
- cudax/ (794 files): Experimental CUDA extensions
- AGENTS.md: NVIDIA's official AI agent instructions for CCCL
- CMakePresets.json: Standardized build configurations
- cccl-version.json: Version tracking

Also added CCCL_ASSET_MAP.md mapping all 4295 CCCL files to
competition value and PRD items.

cccl_upstream now covers 100% of competition-critical assets:
- 27 tuning headers (SM80/90/100 benchmark data)
- 32 dispatch headers (algorithm implementations)
- 60 Thrust examples (correctness verification)
- 217 CUB Catch2 tests (regression matrix)
- 153 CUB benchmarks (parameter space search)
- 18 CUB examples (API verification)
- 27 test helpers + benchmark harness
- 794 cudax experimental extensions
2026-08-06 02:14:18 +00:00

87 lines
2.1 KiB
Plaintext

//===----------------------------------------------------------------------===//
//
// Part of CUDASTF in CUDA C++ Core Libraries,
// under the Apache License v2.0 with LLVM Exceptions.
// See https://llvm.org/LICENSE.txt for license information.
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
// SPDX-FileCopyrightText: Copyright (c) 2022-2024 NVIDIA CORPORATION & AFFILIATES.
//
//===----------------------------------------------------------------------===//
/**
* @file
*
* @brief Freeze data in read-only fashion
*
*/
#include <cuda/experimental/__stf/graph/graph_ctx.cuh>
#include <cuda/experimental/__stf/stream/stream_ctx.cuh>
using namespace cuda::experimental::stf;
int X0(int i)
{
return 17 * i + 45;
}
__global__ void mult(slice<int> s, int val)
{
int tid = blockIdx.x * blockDim.x + threadIdx.x;
int nthreads = gridDim.x * blockDim.x;
for (int i = tid; i < s.size(); i += nthreads)
{
s(i) *= val;
}
}
int main()
{
stream_ctx ctx;
cudaStream_t stream = ctx.pick_stream();
const int N = 16;
int X[N];
for (int i = 0; i < N; i++)
{
X[i] = X0(i);
}
auto lX = ctx.logical_data(X).set_symbol("X");
auto lY = ctx.logical_data(lX.shape()).set_symbol("Y");
for (int k = 0; k < 4; k++)
{
auto fx = ctx.freeze(lX, access_mode::rw, data_place::current_device());
_CCCL_ASSERT(fx.get_access_mode() == access_mode::rw, "invalid access mode");
auto dX = fx.get(data_place::current_device(), stream);
mult<<<8, 4, 0, stream>>>(dX, 4);
fx.unfreeze(stream);
ctx.parallel_for(lX.shape(), lX.read(), lY.write()).set_symbol("Y=X")->*[] __device__(size_t i, auto x, auto y) {
y(i) = x(i);
};
ctx.parallel_for(lX.shape(), lY.rw()).set_symbol("Y+=1")->*[] __device__(size_t i, auto y) {
y(i) += 1;
};
// ctx.host_launch(lX.read(), lY.read())->*[](auto x, auto y) {
// for (int i = 0; i < x.size(); i++) {
// EXPECT(x(i) == 2*X0(i) + 4);
// }
//
// for (int i = 0; i < y.size(); i++) {
// EXPECT(y(i) == 2*X0(i) + 4);
// }
// };
}
ctx.finalize();
}